@@ -1,6 +1,6 @@
 package Data::Verifier::Filters;
 BEGIN {
-  $Data::Verifier::Filters::VERSION = '0.42';
+  $Data::Verifier::Filters::VERSION = '0.43';
 }
 use strict;
 
@@ -46,13 +46,17 @@ Data::Verifier::Filters - Filters for values
 
 =head1 SYNOPSIS
 
-    $dv->verify({
+    use Data::Verifier;
+
+    my $dv = Data::Verifier->new(profile => {
         name => {
-            type    => 'Str'
+            type    => 'Str',
             filters => [ qw(collapse trim) ]
         }
     });
-    $dv->get_value('name');
+
+    $dv->verify({ name => ' foo  bar  '});
+    $dv->get_value('name'); # 'foo bar'
 
 =head1 CUSTOM FILTERS
 
